window.Gleam.initSearch([{"doc":"string_width","title":"string_width","content":"# string_width\n\n[![Package Version](https://img.shields.io/hexpm/v/string_width)](https://hex.pm/packages/string_width)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/string_width/)\n\n```sh\ngleam add string_width@3\n```\n\nA small package estimating the required number of cells when printing a string on the terminal. It supports all Gleam targets, handles ANSI escape codes, includes useful layout functions, and passes the tests of the NPM [string-width](https://www.npmjs.com/package/string-width) package, among others.\n\nIt is also one of the fastest options available, even including target-specific ones, while still providing you full flexibility and correctness.\n\n```gleam\nimport string_width\n\npub fn main() {\n  string_width.dimensions(&quot;hello,\\n안녕하세요&quot;)\n  // --&gt; string_width.Size(rows: 2, columns: 10)\n\n  string_width.line_with(\n    &quot;👩‍👩‍👦‍👦&quot;,\n    string_width.new() |&gt; string_width.mode_2027,\n  )\n  // --&gt; 2\n\n  // word wrapping and truncation\n  string_width.limit(\n    &quot;Lorem ipsum dolor sit amet\\nIs a common placeholder string&quot;,\n    to: Size(rows: 3, columns: 10),\n    ellipsis: &quot;...&quot;\n  )\n  // --&gt; &quot;Lorem ipsum dolor\\nsit amet\\nIs a common place...&quot;\n\n  // position a string inside a box\n  string_width.position(\n    &quot;XXX&quot;,\n    in: Size(rows: 3, columns: 10),\n    align: Center,\n    place: Middle,\n    with: &quot;.&quot;\n  )\n  // --&gt; &quot;..........\\n...XXX....\\n..........&quot;\n}\n```\n\n\n### Limitations\n\n- Many terminals don&#39;t support grapheme clusters properly, so by default, the\n  values returned by this library try to match the behaviour of libc instead\n  of modern text rendering pipelines.\n\n  If you encounter a mismatch that is consistent across multiple environments,\n  feel free to open an issue or ping me on Discord!\n\n- The behaviour when encountering stray variant selectors does not match other similar libraries.\n\n\n### Sources\n\nThe table lookup technique used by this library is heavily based on the musl libc `wcwidth` implementation. I built updated tables using the Unicode 16.0 data, and added support for ambiguous characters. It also uses the regex of the ansi-regex npm package, and the test cases of the string-width npm package.\n\n\n- **UAX #11 East Asian Width:** [https://www.unicode.org/reports/tr11/](https://www.unicode.org/reports/tr11/)\n- **Grapheme Clusters in Terminals:** [https://mitchellh.com/writing/grapheme-clusters-in-terminals](https://mitchellh.com/writing/grapheme-clusters-in-terminals)\n- **get-east-asian-width:** [https://github.com/sindresorhus/get-east-asian-width](https://github.com/sindresorhus/get-east-asian-width)\n- **string-width:** [https://github.com/sindresorhus/string-width](https://github.com/sindresorhus/string-width)\n- **ansi-regex:** [https://github.com/chalk/ansi-regex](https://github.com/chalk/ansi-regex)\n- **musl-libc wcwidth:** [https://git.musl-libc.org/cgit/musl/tree/src/ctype/wcwidth.c](https://git.musl-libc.org/cgit/musl/tree/src/ctype/wcwidth.c)\n- **glibc wcwidth:** [https://sourceware.org/git/?p=glibc.git;a=blob;f=wcsmbs/wcwidth.h;hb=HEAD](https://sourceware.org/git/?p=glibc.git;a=blob;f=wcsmbs/wcwidth.h;hb=HEAD)\n","url":"index.html"},{"doc":"string_width","title":"string_width","content":"# Comparison\n\nCompared to many other libraries in this space, the main focus of this one is\nmeasuring the real width of things when printed to terminal emulators. This\nlibrary does **not** try to guess what font shaping (especially ligatures) would\ndo, and cares **less** about the way things look like in other monospace contexts,\nsuch as using a modern rendering pipeline (e.g. in a browser) but with a monospace\nfont. I encourage you to use your font rendering library directly, or find a way\nto layout things without needing to know the size of your text.\n\n# Unicode version\n\nThe data files are taken from the Unicode 16 release (Sep 2024).\n\n# Algorithm\n\nComponents (codepoints, control sequences and grapheme clusters) are classified\ninto 4 catgories:\n\n- **zero-width:** these do not advance the current column\n- **narrow:** these advance the cursor by one column\n- **wide:** these advance the cursor by two columns\n- **ambiguous:** these advance the cursor either by one or two columns, depending\n  on the `ambiguous_as_wide` option.\n\nControl characters and ansi escape sequences are ignored and reported as zero-width,\n**except**:\n\n - Newlines (`\\n` and `\\r\\n`)  increase the current row, while resetting the column.\n - Tabs (`\\t`) increase the current column to the next tab stop.\n\nFor the remaining string, 3 different modes are supported: `wcwidth`, `mode_2027`\nand `mode2027_ext`.\n\n## Default mode (`wcwidth`)\n\nBy default, this library tries to match the output of the `wcwidth` function from\nglibc. This function is still widely used by the majority of terminal emulators.\n\nIn this mode, the width of a string is the sum of the widths of its individual\ncode points. (Extended) grapheme cluster boundaries are ignored.\n\n## (Extended) Mode 2027\n\n_Mode 2027_ is a proposed mode for terminal emulators that applications can\nrequest. When active and supported, the terminal emulator is supposed to follow\nthe [terminal unicode core spec](https://github.com/contour-terminal/terminal-unicode-core).\nThis mode is supported by some terminals, and even the default and only\nbehaviour in some others.\n\nNone of the terminals I tested implement the proposed spec fully, and the exact\nbehaviour is subject to ongoing discussion in the freedesktop.org terminal\nworking group. Support for this mode should therefore be considered best-effort\nat the moment, especially when support for Brahmic, Arabic, and some east asian\nscripts is required. If you just want your emoji family to be 2 columns wide,\nthis mode works well enough right now.\n\nThis library does the following:\n\n- Extended grapheme clusters are segmented based on the `pop_grapheme` function.\n  This function uses native target code, and is therefore not guaranteed to match\n  the unicode version of this library (at the time of writing,\n  Erlang uses 15.0, and Node.JS uses 15.1).\n- The width of a grapheme cluster is the _maximum_ width of all codepoints\n  that make it up.\n- If a grapheme cluster contains U+FE0F Variant Selector 16 in addition to\n  another non-zero-width codepoint, its width is wide.\n\nAdditionally, in the extended mode, the following rules apply:\n\n- If a grapheme cluster contains two or more non-spacing non-zero-width\n  codepoints, its width is wide. &quot;Spacing&quot; codepoints in this context are all\n  codepoints with a `General_Category` of `Spacing_Mark`.\n\nThis rule makes the width reported by this library across Erlang and Nodejs more\nstable (Unicode version differences, see above), as well as closer match the\nbehaviour of actual terminals with mode 2027 support. Starting with Unicode 15.1,\nsome sequences that ocupy multiple columns are now segmented into single\ngrapheme clusters.\n\n\n## Width of a single codepoint\n\nThe following codepoints are classified as **zero-with:**\n\n- All codepoints with the `Default_Ignorable_Code_Point` property, **except** for U+115F Hangul Choseong Filler.\n- All codepoints with a `General_Category` of `Control`, `Enclosing_Mark`, `Nonspacing_Mark`, `Paragraph_Separator`, or `Line_Separator`.\n- All codepoints with `Hangul_Syllable_Type` of Vowel or Trailing Jamo.\n- All codepoints marked as `Prepended_Concatenation_Mark`\n- `U+fff9..U+fffb`, interlinear annotation format characters\n- `U+13430..U+13440`, egyptian hieroglyph format characters\n\nThe following codepoints are classified as **wide:**\n\n- All codepoints with the `Emoji_Presentation` property set.\n- All codepoints with an `East_Asian_Width` of Wide or Fullwidth.\n\nThe following codepoints are classified as **ambiguous:**\n\n- All codepoints with an `East_Asian_Width` of Ambiguous.\n\nAll other codepoints are **narrow**.\n\n# Testing\n\nI currently test against VTE (mainly gnome-terminal), Windows Terminal, Kitty,\nand foot for mode 2027 support. I also test on Contour since they originally\nproposed the mode 2027 spec; however, they use a custom Unicode library that I\ndon&#39;t trust fully.\n\nWhen reporting a mismatch, please include which terminal and the escaped\ncodepoints. Gitlab/Discord sometimes like to strip certain modifiers.\n","url":"internals.html"},{"doc":"string_width","title":"Alignment","content":"pub type Alignment {\n  Left\n  Center\n  Right\n}\n Control the text or box alignment on the horizontal axis.\nLeft\n\n\nCenter\n\n\nRight\n\n\nSynonyms:\nstring_width.Alignment\nstring_width Alignment","url":"string_width.html#Alignment"},{"doc":"string_width","title":"Options","content":"pub opaque type Options\n Options to change the default behaviour of the functions in this library.\n If you are unsure what to do here, the defaults should work great!\n\nSynonyms:\nstring_width.Options\nstring_width Options","url":"string_width.html#Options"},{"doc":"string_width","title":"Piece","content":"pub type Piece {\n  Piece(piece: String, row: Int, column: Int, width: Int)\n}\n The measured pieces of a string, passed to you by `fold` and `fold_with`\nPiece(piece: String, row: Int, column: Int, width: Int)\n\n\nSynonyms:\nstring_width.Piece\nstring_width Piece","url":"string_width.html#Piece"},{"doc":"string_width","title":"Placement","content":"pub type Placement {\n  Top\n  Middle\n  Bottom\n}\n Control the box alignment on the vertical axis.\nTop\n\n\nMiddle\n\n\nBottom\n\n\nSynonyms:\nstring_width.Placement\nstring_width Placement","url":"string_width.html#Placement"},{"doc":"string_width","title":"Size","content":"pub type Size {\n  Size(rows: Int, columns: Int)\n}\n A custom type making it easy to differentiate the width (columns) and\n height (rows).\nSize(rows: Int, columns: Int)\n\n\nSynonyms:\nstring_width.Size\nstring_width Size","url":"string_width.html#Size"},{"doc":"string_width","title":"align","content":"pub fn align(\n  str: String,\n  to max_width: Int,\n  align alignment: Alignment,\n  with space: String,\n) -&gt; String\n Align each line horizontally, using a spacer character or string as a filler.\n Each line of the return value will be at least `max_width` wide.\n\n If a line is already longer than the max width, it will not be changed.\n If the space strings width does not evenly divide the missing amount of\n columns, the extra spacer will overflow the max width.\n\n ### Examples\n\n \n align(&quot;hello&quot;, to: 10, align: Left, with: &quot; &quot;)\n // --&gt; &quot;hello     &quot;\n\n align(&quot;12345&quot;, to: 8, align: Right, with: &quot;0&quot;)\n // --&gt; &quot;00012345&quot;\n\n align(&quot; Welcome &quot;, to: 20, align: Center, with: &quot;==&quot;)\n // --&gt; &quot;====== Welcome ======&quot; // (len = 21)\n \nSynonyms:\nstring_width.align\nstring_width align","url":"string_width.html#align"},{"doc":"string_width","title":"align_with","content":"pub fn align_with(\n  str: String,\n  to max_width: Int,\n  align alignment: Alignment,\n  using options: Options,\n  with space: String,\n) -&gt; String\n Like `align`, bu use custom options for measure.\nSynonyms:\nstring_width.align_with\nstring_width align_with","url":"string_width.html#align_with"},{"doc":"string_width","title":"ambiguous_as_wide","content":"pub fn ambiguous_as_wide(options: Options) -&gt; Options\n Some characters are marked by Unicode as &quot;ambiguous&quot;, meaning they may\n occupy 1 or 2 cells, depending on the context, current language, selected\n font, surrounding text, and more.\n\n Unicode recommends treating these characters as narrow by default,\n but you can change this behaviour using this option.\nSynonyms:\nstring_width.ambiguous_as_wide\nstring_width ambiguous_as_wide","url":"string_width.html#ambiguous_as_wide"},{"doc":"string_width","title":"at_tab_offset","content":"pub fn at_tab_offset(\n  options: Options,\n  tab_offset: Int,\n) -&gt; Options\n Define an _offset_ for tab stop calculations. (Default: 0)\n\n If the text you print doesn&#39;t start at the first column, but is instead\n indented somehow, you can set this option to this number to make sure tab\n stops are correctly calculated.\nSynonyms:\nstring_width.at_tab_offset\nstring_width at_tab_offset","url":"string_width.html#at_tab_offset"},{"doc":"string_width","title":"count_ansi_codes","content":"pub fn count_ansi_codes(options: Options) -&gt; Options\n Do not ignore ansi escape sequences, and count them as regular characters.\n\n You can enable this option as an optimisation if you are sure that your\n string doesn&#39;t contain any ansi escape codes.\nSynonyms:\nstring_width.count_ansi_codes\nstring_width count_ansi_codes","url":"string_width.html#count_ansi_codes"},{"doc":"string_width","title":"dimensions","content":"pub fn dimensions(str: String) -&gt; Size\n The required number of rows and columns to display the given text.\n\n The number of rows is equal to the number of lines, while the number of\n columns represents the maximum line width.\n\n ### Examples\n\n \n dimensions(&quot;안녕하세요&quot;)\n // --&gt; Size(rows: 1, columns: 10)\n\n dimensions(&quot;hello,\\n안녕하세요&quot;)\n // --&gt; Size(rows: 2, columns: 10)\n \nSynonyms:\nstring_width.dimensions\nstring_width dimensions","url":"string_width.html#dimensions"},{"doc":"string_width","title":"dimensions_with","content":"pub fn dimensions_with(str: String, options: Options) -&gt; Size\n Like `dimensions`, but use custom options.\nSynonyms:\nstring_width.dimensions_with\nstring_width dimensions_with","url":"string_width.html#dimensions_with"},{"doc":"string_width","title":"fold","content":"pub fn fold(\n  over str: String,\n  from state: a,\n  with fun: fn(a, Piece) -&gt; a,\n) -&gt; a\n A higher-level `fold` that keeps track of the position inside of the string.\n\n Handles tabs and newlines, and always passes full grapheme clusters,\n regardless of options. Concatenating the graphemes produces the original string.\n\n Intended to be used as a basis for custom layout algorithms.\nSynonyms:\nstring_width.fold\nstring_width fold","url":"string_width.html#fold"},{"doc":"string_width","title":"fold_raw","content":"pub fn fold_raw(\n  over string: String,\n  using options: Options,\n  from state: a,\n  with fun: fn(a, String, Int) -&gt; a,\n) -&gt; a\n A low-level fold that iterate over the measured components of a string.\n Components are either graphemes or codepoints depending on the `mode` option,\n or other undivisible sequences, like ANSI escape codes.\n\n This function does not by itself keep track of any additional state, and\n doesn&#39;t for example handle newlines or tabs like `fold` would.\n If you know that your algorithm is safe and won&#39;t break up graphemes (or\n maybe this is acceptable), you can use this fold variant instead as a\n performance optimisation.\n\n Concatenating all components is guaranteed to produce the original string.\n\n ### Examples\n\n \n // A slower string_width.line implementation that doesn&#39;t handle tabs\n fold_raw(&quot;hello&quot;, new(), from: 0, with: fn(so_far, _chr, width) { width + so_far })\n // --&gt; 5\n \n\n \n // truncate a string after 50 characters, but keep all ansi sequences.\n use #(total, acc), chr, width &lt;- fold_raw(input, new(), from: #(0, &quot;&quot;))\n case total &gt;= 50 {\n   True -&gt; case chr {\n     &quot;\\u{1b}&quot; &lt;&gt; _ -&gt; #(total, acc &lt;&gt; chr)\n      _ -&gt; #(total, acc)\n   }\n\n   False -&gt; #(total + width, acc &lt;&gt; chr)\n }\n \nSynonyms:\nstring_width.fold_raw\nstring_width fold_raw","url":"string_width.html#fold_raw"},{"doc":"string_width","title":"fold_with","content":"pub fn fold_with(\n  over str: String,\n  using options: Options,\n  from state: a,\n  with fun: fn(a, Piece) -&gt; a,\n) -&gt; a\n A higher-level `fold` that keeps track of the position inside of the string\n\n Handles tabs and newlines, and always passes full grapheme clusters,\n regardless of options. Concatenating the graphemes produces the original string.\n\n Intended to be used as a basis for custom layout algorithms.\nSynonyms:\nstring_width.fold_with\nstring_width fold_with","url":"string_width.html#fold_with"},{"doc":"string_width","title":"is_ansi_component","content":"pub fn is_ansi_component(str: String, options: Options) -&gt; Bool\n Returns true if a given component string recieved in `fold` is an ANSI\n escape sequence.\nSynonyms:\nstring_width.is_ansi_component\nstring_width is_ansi_component","url":"string_width.html#is_ansi_component"},{"doc":"string_width","title":"limit","content":"pub fn limit(\n  str: String,\n  to max_size: Size,\n  ellipsis ellipsis: String,\n) -&gt; String\n Limit the dimensions of a string, either by wrapping on white space\n characters, or by truncating the last line and appending an ellipsis.\n\n The lines of the resulting string are left aligned and are at most `columns`\n wide. If a single word is longer than the maximum allowed line width, the\n word is broken into 2 pieces at the grapheme level. If the string gets\n truncated, this function will keep collecting ANSI sequences to make sure\n all formatting is preserved.\n\n A commonly used ellipsis character is `&quot;…&quot;`, also known as\n U+2026 HORIZONTAL ELLIPSIS.\n\n ### Examples\n\n \n limit(&quot;Hello World&quot;, Size(rows: 1, columns: 10), ellipsis: &quot;...&quot;)\n // --&gt; &quot;Hello W...&quot;\n\n limit(&quot;Hello World&quot;, Size(rows: 2, columns: 5), ellipsis: &quot;...&quot;)\n // --&gt; &quot;Hello\\nWorld&quot;\n \nSynonyms:\nstring_width.limit\nstring_width limit","url":"string_width.html#limit"},{"doc":"string_width","title":"limit_with","content":"pub fn limit_with(\n  str: String,\n  to max_size: Size,\n  using options: Options,\n  ellipsis ellipsis: String,\n) -&gt; String\n Like `limit`, but also customise the options used for measuring.\nSynonyms:\nstring_width.limit_with\nstring_width limit_with","url":"string_width.html#limit_with"},{"doc":"string_width","title":"line","content":"pub fn line(str: String) -&gt; Int\n Get the number of columns required to print a line in a terminal.\n\n If multiple lines are given, the length of the longest line is returned.\n\n ### Examples\n\n \n line(&quot;äöüè&quot;)\n // --&gt; 4\n\n line(&quot;안녕하세요&quot;)\n // --&gt; 10\n\n line(&quot;👩‍👩‍👦‍👦&quot;)\n // --&gt; 8\n\n line(&quot;\\u{1B}[31mhello\\u{1B}[39m&quot;)\n // --&gt; 5\n \nSynonyms:\nstring_width.line\nstring_width line","url":"string_width.html#line"},{"doc":"string_width","title":"line_with","content":"pub fn line_with(str: String, options: Options) -&gt; Int\n Like `line`, but use custom options.\n\n ### Example\n\n \n let options =\n   new()\n   |&gt; mode\n\n line_with(&quot;👩‍👩‍👦‍👦&quot;, options)\n // --&gt; 2\n \nSynonyms:\nstring_width.line_with\nstring_width line_with","url":"string_width.html#line_with"},{"doc":"string_width","title":"mode_2027","content":"pub fn mode_2027(options: Options) -&gt; Options\n Measure grapheme clusters instead of individual code points.\n\n Most terminal emulators do not handle grapheme clusters well and will\n instead show their decomposition. To make sure a given string always fits\n even on those terminals, the functions in this package will copy this\n behaviour as well.\n\n If you enable this option, the returned numbers will more accurately represent\n the width of a string on a website or in an editor.\n\n **NOTE:** Grapheme support in terminals is highly experimental and subject\n to ongoing discussion! When working on CLIs or TUIs, you do not want to use\n this option most of the time.\n\n See also [Grapheme Clusters and Terminal Emulators](https://mitchellh.com/writing/grapheme-clusters-in-terminals)\n for a better explanation on how terminals behave.\nSynonyms:\nstring_width.mode_2027\nstring_width mode_2027","url":"string_width.html#mode_2027"},{"doc":"string_width","title":"mode_2027_ext","content":"pub fn mode_2027_ext(options: Options) -&gt; Options\n Measure grapheme clusters instead of individual code points, and always\n treat grapheme clusters with more than one non-modifier character as wide.\n\n This is a custom extension to Unicode Core. Many single grapheme clusters\n would currently still render as wide glyphs in many contexts, since font\n shaping would not be able to collapse them into a single narrow &quot;ligature&quot;.\n\n This mode is an additional heuristic that tries to handle more such cases.\n\n See `mode_2027` for more explanation on the implications.\nSynonyms:\nstring_width.mode_2027_ext\nstring_width mode_2027_ext","url":"string_width.html#mode_2027_ext"},{"doc":"string_width","title":"mode_wcwidth","content":"pub fn mode_wcwidth(options: Options) -&gt; Options\n The default mode and the mode suitable for most terminals.\n\n Measures individual code points, similar to the libc `wcwidth` function\n that almost all of these terminals use.\n\n Note that except for `fold_raw`, this library will still always process\n grapheme clusters as a unit.\nSynonyms:\nstring_width.mode_wcwidth\nstring_width mode_wcwidth","url":"string_width.html#mode_wcwidth"},{"doc":"string_width","title":"new","content":"pub fn new() -&gt; Options\n Start building up new options.\nSynonyms:\nstring_width.new\nstring_width new","url":"string_width.html#new"},{"doc":"string_width","title":"position","content":"pub fn position(\n  str: String,\n  in bounding_box: Size,\n  align alignment: Alignment,\n  place placement: Placement,\n  with space: String,\n) -&gt; String\n Position the string area inside a bigger box without changing text alignment.\n The box will be filled with the space character.\n\n If a line is already bigger than the maximum width, it will not be changed.\n If there are more lines than the maximum amount of rows, the extra lines\n will still be kept.\n If the space strings&#39; width does not evenly divide the missing amount of\n columns, the extra spacer will overflow the max width.\n\n ### Examples\n\n \n position(&quot;X&quot;, in: Size(3, 3), align: Center, place: Middle, with: &quot;o&quot;)\n // --&gt; &quot;ooo\\noXo\\nooo&quot;\n \nSynonyms:\nstring_width.position\nstring_width position","url":"string_width.html#position"},{"doc":"string_width","title":"position_with","content":"pub fn position_with(\n  str: String,\n  in bounding_box: Size,\n  horizontal alignment: Alignment,\n  vertical placement: Placement,\n  using options: Options,\n  with space: String,\n) -&gt; String\n Like `position`, but use custom options to measure each line.\nSynonyms:\nstring_width.position_with\nstring_width position_with","url":"string_width.html#position_with"},{"doc":"string_width","title":"tabs_to_spaces","content":"pub fn tabs_to_spaces(str: String) -&gt; String\n Replace all tab characters found in the string with the amount of spaces\n that this tab would have had otherwise.\n\n This makes it safe to prepend to a line, without changing the spacing produced\n by tabs anymore.\n\n ### Examples\n\n \n tabs_to_spaces(&quot;Hello\\tWorld&quot;)\n // --&gt; &quot;Hello   World&quot; // 3 spaces\n \nSynonyms:\nstring_width.tabs_to_spaces\nstring_width tabs_to_spaces","url":"string_width.html#tabs_to_spaces"},{"doc":"string_width","title":"tabs_to_spaces_with","content":"pub fn tabs_to_spaces_with(\n  str: String,\n  using options: Options,\n) -&gt; String\n Like `tabs_to_spaces`, but customise the opttions as well.\n\n **NB:** You can use `at_tab_offset` and `with_tab_width` to change the measure of\n tab characters inside the string!\n\n \n let options = new() |&gt; with_tab_width(4)\n tabs_to_spaces_with(&quot;hi\\tcutie~&quot;, options)\n // --&gt; &quot;hi  cutie~&quot;\n \nSynonyms:\nstring_width.tabs_to_spaces_with\nstring_width tabs_to_spaces_with","url":"string_width.html#tabs_to_spaces_with"},{"doc":"string_width","title":"with_tab_width","content":"pub fn with_tab_width(\n  options: Options,\n  tab_width: Int,\n) -&gt; Options\n Change the number of columns between tab stops. (Default: 8)\n\n Whenever a tab character `\\t` is encountered, the current column number will\n be rounded up to the next multiple of this number.\nSynonyms:\nstring_width.with_tab_width\nstring_width with_tab_width","url":"string_width.html#with_tab_width"},{"doc":"string_width","title":"string_width","content":" #### Measure\n [line](#line), [line_with](#line_with),\n [dimensions](#dimensions), [dimensions_with](#dimensions_with)\n\n #### Layout\n [limit](#limit), [limit_with](#limit_with),\n [position](#position), [position_with](#position_with),\n [align](#align), [align_with](#align_with),\n [tabs_to_spaces](#tabs_to_spaces), [tabs_to_spaces_with](#tabs_to_spaces_with)\n\n #### Options Builder\n [new](#new),\n [ambiguous_as_wide](#ambiguous_as_wide), [count_ansi_codes](#count_ansi_codes),\n [mode_2027](#mode_2027), [mode_2027_ext](#mode_2027_ext), [mode_wcwidth](#mode_wcwidth),\n [at_tab_offset](#at_tab_offset), [with_tab_width](#with_tab_width)\n\n #### Advanced\n [fold](#fold), [fold_with](#fold_with), [fold_raw](#fold_raw),\n [is_ansi_component](#is_ansi_component)\n","url":"string_width.html"}]);